import React from 'react';
import { Text, Title, Section, Paragraph, Image, Button, Remark, Hr, File, Video, CountDown, Card, Container } from '@kaiheila/kui-lib';
import MarkdownMessageText from "../../components/MarkdownMessageText";
import { printEmoji, printReactEmoji } from "../emoji/emoji";
import MusicPlayer from "../../components/MusicPlayer";
import CardVideoWrapper from "../../components/CardVideoWrapper";
function parseModule(module, cardSize, options) {
  var _options$customFileEv, _options$customVideoE, _options$customVideoE2, _options$customAudioE, _options$customAudioE2;
  if (typeof module === 'string') {
    return /*#__PURE__*/React.createElement(Text, null, /*#__PURE__*/React.createElement("span", {
      dangerouslySetInnerHTML: {
        __html: printEmoji(module)
      }
    }));
  } else if (!module) {
    return '';
  }
  var _module$elements = module.elements,
    elements = _module$elements === void 0 ? [] : _module$elements,
    type = module.type,
    content = module.content;
  var childContent = null;
  var fragment = null;
  switch (type) {
    case 'plain-text':
      fragment = /*#__PURE__*/React.createElement(Text, null, /*#__PURE__*/React.createElement("span", {
        dangerouslySetInnerHTML: {
          __html: printEmoji(content)
        }
      }));
      break;
    case 'header':
      childContent = typeof module.text === 'string' ? /*#__PURE__*/React.createElement(React.Fragment, null, printReactEmoji(module.text)) : parseModule(module.text, cardSize, options);
      fragment = /*#__PURE__*/React.createElement(Title, null, childContent);
      break;
    case 'section':
      fragment = /*#__PURE__*/React.createElement(Section, {
        accessory: module.accessory ? parseModule(module.accessory, cardSize, options) : null,
        mode: module.mode,
        size: cardSize,
        colume: cardSize === 'sm' && module.accessory && module.accessory.type === 'button' ? true : false
      }, parseModule(module.text, cardSize, options));
      break;
    case 'paragraph':
      fragment = /*#__PURE__*/React.createElement(Paragraph, {
        size: cardSize,
        cols: module.cols,
        childrens: parseModuleList(module.fields, cardSize, options)
      });
      break;
    case 'container':
      fragment = /*#__PURE__*/React.createElement(Container, {
        size: cardSize,
        elements: module.elements,
        onClickElement: function onClickElement(module) {
          if (module.type === 'image' && typeof options.customImageClick === 'function') options.customImageClick(module);
        }
      });
      break;
    case 'image-group':
      fragment = /*#__PURE__*/React.createElement(Image.Group, {
        list: elements,
        onClick: function onClick(module) {
          if (typeof options.customImageClick === 'function') options.customImageClick(module);
        }
      });
      break;
    case 'action-group':
      fragment = /*#__PURE__*/React.createElement(Button.Wrapper, null, parseModuleList(module.elements, cardSize, options));
      break;
    case 'button':
      childContent = parseModule(module.text, cardSize, options);
      fragment = /*#__PURE__*/React.createElement(Button, {
        block: cardSize === 'sm',
        type: module.theme,
        color: module.color,
        onClick: function onClick() {
          if (typeof options.customButtonClick === 'function') options.customButtonClick(module);
        }
      }, childContent);
      break;
    case 'context':
      fragment = /*#__PURE__*/React.createElement(Remark, null, parseModuleList(elements, cardSize, options));
      break;
    case 'divider':
      fragment = /*#__PURE__*/React.createElement(Hr, null);
      break;
    case 'file':
      fragment = /*#__PURE__*/React.createElement(File, {
        src: module.src,
        outside: module.external,
        fileName: module.title,
        fileSize: module.size,
        onClickDown: (_options$customFileEv = options.customFileEvents) !== null && _options$customFileEv !== void 0 && _options$customFileEv.onDownload ? function () {
          options.customFileEvents.onDownload(module);
        } : undefined
      });
      break;
    case 'video':
      fragment = /*#__PURE__*/React.createElement(CardVideoWrapper, {
        src: module.src,
        outside: module.external,
        size: cardSize,
        title: module.title,
        fileSize: module.size,
        duration: module.duration,
        poster: module.cover,
        onClickPlay: typeof (options === null || options === void 0 || (_options$customVideoE = options.customVideoEvents) === null || _options$customVideoE === void 0 ? void 0 : _options$customVideoE.onPlay) === 'function' ? function () {
          options.customVideoEvents.onPlay(module);
        } : undefined,
        onClickDown: typeof (options === null || options === void 0 || (_options$customVideoE2 = options.customVideoEvents) === null || _options$customVideoE2 === void 0 ? void 0 : _options$customVideoE2.onDownload) === 'function' ? function () {
          options.customVideoEvents.onDownload(module);
        } : undefined
      });
      break;
    case 'audio':
      fragment = /*#__PURE__*/React.createElement(MusicPlayer, {
        src: module.src,
        outside: module.external,
        fileName: module.title,
        fileSize: module.size,
        controls: cardSize !== 'sm',
        duration: module.duration,
        icon: module.cover,
        id: "".concat(module === null || module === void 0 ? void 0 : module.src).concat(module === null || module === void 0 ? void 0 : module.title),
        canDownload: module.canDownload,
        onClickPlay: typeof (options === null || options === void 0 || (_options$customAudioE = options.customAudioEvents) === null || _options$customAudioE === void 0 ? void 0 : _options$customAudioE.onPlay) === 'function' ? function () {
          options.customAudioEvents.onPlay(module);
        } : undefined,
        onClickDown: typeof (options === null || options === void 0 || (_options$customAudioE2 = options.customAudioEvents) === null || _options$customAudioE2 === void 0 ? void 0 : _options$customAudioE2.onDownload) === 'function' ? function () {
          options.customAudioEvents.onDownload(module);
        } : undefined
      });
      break;
    case 'countdown':
      if (module.mode === 'hour') {
        fragment = /*#__PURE__*/React.createElement(CountDown.Hour, {
          endTime: module.endTime,
          size: cardSize
        });
      } else if (module.mode === 'day') {
        fragment = /*#__PURE__*/React.createElement(CountDown.Day, {
          endTime: module.endTime
        });
      } else {
        var _module$startTime = module.startTime,
          startTime = _module$startTime === void 0 ? 0 : _module$startTime,
          _module$endTime = module.endTime,
          endTime = _module$endTime === void 0 ? 0 : _module$endTime;
        var duration = endTime - startTime;
        fragment = /*#__PURE__*/React.createElement(CountDown, {
          startTime: startTime,
          duration: duration
        });
      }
      break;
    case 'kmarkdown':
      fragment = /*#__PURE__*/React.createElement(MarkdownMessageText, {
        content: content,
        options: options
      });
      break;
  }
  return fragment;
}
function parseModuleList(moduleList, cardSize, options) {
  moduleList = moduleList || [];
  return moduleList.map(function (module, i) {
    return /*#__PURE__*/React.createElement(React.Fragment, {
      key: i
    }, parseModule(module, cardSize, options));
  });
}

// 将JSON 转换为 对应元素
export function json2fragment(cardList, options) {
  return cardList.map(function (card, i) {
    var _card$modules = card.modules,
      modules = _card$modules === void 0 ? [] : _card$modules,
      color = card.color,
      size = card.size,
      theme = card.theme;
    return /*#__PURE__*/React.createElement(Card, {
      color: color,
      theme: theme,
      size: size,
      key: i,
      hideMoreHeight: options.hideMoreHeight,
      collapsed: options.collapsed
    }, parseModuleList(modules, size, options));
  });
}