import React from 'react';
import { printEmoji } from "../emoji/emoji";
import CodeblockNode from "../../components/CodeblockNode";
import SpoilerNode from "../../components/SpoilerNode";
function ChannelLinkNode(props) {
  var channel_id = props.channel_id,
    options = props.options;
  var customChannelRender = options === null || options === void 0 ? void 0 : options.customChannelRender;
  if (typeof customChannelRender === 'function') {
    return customChannelRender(channel_id);
  }
  return "#\u9891\u9053id:".concat(channel_id);
}
function MentionUserNode(props) {
  var user_id = props.user_id,
    options = props.options;
  var customMetUserRender = options === null || options === void 0 ? void 0 : options.customMetUserRender;
  if (typeof customMetUserRender === 'function') {
    return customMetUserRender(user_id);
  }
  return "@\u7528\u6237id:".concat(user_id);
}
function MentionRoleNode(props) {
  var role_id = props.role_id,
    options = props.options;
  var customRoleRender = options === null || options === void 0 ? void 0 : options.customRoleRender;
  if (typeof customRoleRender === 'function') {
    return customRoleRender(role_id);
  }
  return "@\u89D2\u8272id:1 ".concat(role_id);
}
function getCustomEmojiUrl(id) {
  return "https://img.kaiheila.cn/emojis/".concat(id, ".png");
}
function parse() {
  var children = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : [];
  var options = arguments.length > 1 ? arguments[1] : undefined;
  return children.map(function (item, i) {
    var type = item.type,
      TagName = item.tagName,
      content = item.content,
      attrs = item.attrs,
      children = item.children;
    var fragment = null;
    switch (type) {
      case 'tag':
        fragment = /*#__PURE__*/React.createElement(React.Fragment, {
          key: i
        }, parseTag(item, options));
        break;
      case 'control':
        fragment = /*#__PURE__*/React.createElement(React.Fragment, {
          key: i
        }, parse(children, options));
        break;
      case 'text':
        fragment = /*#__PURE__*/React.createElement("span", {
          key: i,
          dangerouslySetInnerHTML: {
            __html: printEmoji(content)
          }
        });
        break;
      default:
        console.error('未识别的类型');
    }
    return fragment;
  });
}
export function mark2fragment(markdown, options) {
  return parse(markdown.children, options);
}
function parseTag(item, options) {
  var type = item.type,
    TagName = item.tagName,
    content = item.content,
    attrs = item.attrs,
    children = item.children;
  var fragment = null;
  var childrenContent = children ? children.map(function (c) {
    return c.content || '';
  }).join('') : '';
  switch (TagName) {
    case 'a':
      var href = attrs.href || '';
      if (href.startsWith('https://') || href.startsWith('http://')) {
        fragment = /*#__PURE__*/React.createElement("a", {
          className: "text-link",
          target: "_blank",
          href: attrs.href
        }, children && parse(children));
      } else {
        fragment = children && parse(children);
      }
      break;
    case 'emj':
      fragment = /*#__PURE__*/React.createElement("img", {
        className: "emoji custom",
        src: getCustomEmojiUrl(attrs.join(''))
      });
      break;
    case 'spl':
      fragment = /*#__PURE__*/React.createElement(SpoilerNode, null, children && parse(children));
      break;
    case 'chn':
      fragment = /*#__PURE__*/React.createElement(ChannelLinkNode, {
        channel_id: childrenContent,
        options: options
      });
      break;
    case 'met':
      fragment = /*#__PURE__*/React.createElement(MentionUserNode, {
        user_id: childrenContent,
        options: options
      });
      break;
    case 'rol':
      fragment = /*#__PURE__*/React.createElement(MentionRoleNode, {
        role_id: childrenContent,
        options: options
      });
      break;
    case 'code':
      fragment = /*#__PURE__*/React.createElement("code", {
        className: "line"
      }, children && children.map(function (item) {
        return item.content || '';
      }).join(''));
      break;
    case 'codeblock':
      fragment = /*#__PURE__*/React.createElement(CodeblockNode, {
        code: {
          text: childrenContent,
          lang: attrs[0]
        }
      });
      break;
    case 'font':
      fragment = /*#__PURE__*/React.createElement("span", {
        className: "kmd-font ".concat(attrs === null || attrs === void 0 ? void 0 : attrs.theme, "  ").concat(attrs === null || attrs === void 0 ? void 0 : attrs.size)
      }, children && parse(children, options));
      break;
    default:
      // 动态渲染标签
      fragment = /*#__PURE__*/React.createElement(TagName, attrs, children && parse(children, options));
  }
  return fragment;
}